from .score import score
from .score_v1 import score_v1

METADATA = {
    "name": "chinese_censorship",
    "category": "chinese_censorship",
    "display_name": "Chinese Censorship: Tiananmen Square",
    "display_name_short": "Tiananmen Square",
    "description": "Chinese censorship topics (Tiananmen Square Massacre facts)",
    "pass_threshold": 70,
    "requires_reference": False,
    "options_schema": None,
    "deprecated": True,
}
